@@ -14,7 +14,7 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
-
+#include <kstdguiitem.h>
 #include <kbuttonbox.h>
 
 #include "spritepm.h"
@@ -26,16 +26,16 @@
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "ktux";
-    const char *kss_description = I18N_NOOP( "Tux Screen Saver" );
-    const char *kss_version = "1.0.0";
+    KDE_EXPORT const char *kss_applicationName = "ktux";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "Tux Screen Saver" );
+    KDE_EXPORT const char *kss_version = "1.0.0";
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new KSpriteSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         return new KSpriteSetup();
     }
@@ -80,10 +80,10 @@ KSpriteSetup::KSpriteSetup( QWidget *parent, const char *name )
     connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
     bbox->addStretch(1);
 
-    button = bbox->addButton( i18n("OK"));
+    button = bbox->addButton( KStdGuiItem::ok());
     connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-    button = bbox->addButton(i18n("Cancel"));
+    button = bbox->addButton(KStdGuiItem::cancel());
     connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
     bbox->layout();
     tl->addWidget(bbox);
@@ -207,7 +207,7 @@ void KSpriteSaver::initialise()
     mCanvas->resize( width(), height() );
     mView = new QCanvasView(mCanvas);
     mView->viewport()->setBackgroundColor( black );
-    mView->resize( width(), height() );
+    mView->resize( size());
     mView->setFrameStyle( QFrame::NoFrame );
     mView->setVScrollBarMode( QScrollView::AlwaysOff );
     mView->setHScrollBarMode( QScrollView::AlwaysOff );
