@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: flow.h,v 1.2 2001/09/29 04:02:04 bruggie Exp $
+** $Id: flow.h 175602 2002-09-03 23:49:21Z waba $
 **
 ** Definition of simple flow layout for custom layout example
 **
@@ -24,13 +24,13 @@ public:
     SimpleFlow( QWidget *parent, int border=0, int space=-1,
 		const char *name=0 )
 	: QLayout( parent, border, space, name ),
-	cached_width(0) {}
+	cached_width(0), cached_hfw(0) {}
     SimpleFlow( QLayout* parent, int space=-1, const char *name=0 )
 	: QLayout( parent, space, name ),
-	cached_width(0) {}
+	cached_width(0), cached_hfw(0) {}
     SimpleFlow( int space=-1, const char *name=0 )
 	: QLayout( space, name ),
-	cached_width(0) {}
+	cached_width(0), cached_hfw(0) {}
 
     ~SimpleFlow();
 
@@ -50,7 +50,6 @@ private:
     QPtrList<QLayoutItem> list;
     int cached_width;
     int cached_hfw;
-
 };
 
 #endif
